import sys
 
import maya.OpenMaya as OpenMaya
import maya.OpenMayaMPx as OpenMayaMPx
 
kPluginNodeTypeName = "projectMesh"
 
kPluginNodeId = OpenMaya.MTypeId( 0x80000 )
 
# Node definition
class projectMeshNode( OpenMayaMPx.MPxNode ) :
 
	# constructor
	def __init__( self ) :
 
		OpenMayaMPx.MPxNode.__init__( self )
 
 
	def compute( self, plug, data ) :
 
		print "compute"
		return OpenMaya.MStatus.kSuccess
 
 
# creator
def nodeCreator():
	return OpenMayaMPx.asMPxPtr( projectMeshNode() )
 
# initializer
def nodeInitializer() :
	typedAttr = OpenMaya.MFnTypedAttribute()
 
	# Setup the input attributes
	projectMeshNode.inputMeshSrc = typedAttr.create( "inputMeshSrc", "inMeshSrc", OpenMaya.MFnData.kMesh )
	typedAttr.setReadable(False)
 
	projectMeshNode.inputMeshTarget = typedAttr.create( "inputMeshTarget", "inMeshTrg", OpenMaya.MFnData.kMesh )
	typedAttr.setReadable(False)
 
	# Setup the output attributes
	projectMeshNode.outputMesh = typedAttr.create( "outputMesh", "outMesh", OpenMaya.MFnData.kMesh )
	typedAttr.setWritable(False)
	typedAttr.setStorable(False)
 
	# Add the attributes to the node
	projectMeshNode.addAttribute( projectMeshNode.inputMeshSrc )
	projectMeshNode.addAttribute( projectMeshNode.inputMeshTarget )
	projectMeshNode.addAttribute( projectMeshNode.outputMesh )
 
	# Set the attribute dependencies
	projectMeshNode.attributeAffects( projectMeshNode.inputMeshSrc, projectMeshNode.outputMesh )
	projectMeshNode.attributeAffects( projectMeshNode.inputMeshTarget, projectMeshNode.outputMesh )
 
 
 
# initialize the script plug-in
def initializePlugin( mobject ) :
	mplugin = OpenMayaMPx.MFnPlugin( mobject )
	try:
		mplugin.registerNode( kPluginNodeTypeName, kPluginNodeId, nodeCreator, nodeInitializer )
	except:
		sys.stderr.write( "Failed to register node: %s\n" % kPluginNodeTypeName )
		raise
 
 
# uninitialize the script plug-in
def uninitializePlugin( mobject ):
	mplugin = OpenMayaMPx.MFnPlugin( mobject )
	try:
		mplugin.deregisterNode( kPluginNodeId )
	except:
		sys.stderr.write( "Failed to unregister node: %s\n" % kPluginNodeTypeName )
		raise